About the Copyright Holders
===========================

*   Copyright (c) 2013, Sandia National Laboratories

    Sandia National Laboratories developed pvlib python based on code in
    PVLib MATLAB.

*   Copyright (c) 2014-2018, pvlib python Development Team

    The pvlib python Development Team is the collection of developers of the
    pvlib python project.

Full credits for pvlib python contributors can be found in the documentation.

Our Copyright Policy
====================

pvlib python uses a shared copyright model. Each contributor maintains copyright
over their contributions to pvlib python. However, it is important to note that
these contributions are typically only changes to the repositories. Thus,
the pvlib python source code, in its entirety, is not the copyright of any single
person or institution. Instead, it is the collective copyright of the
entire pvlib python Development Team. If individual contributors want to maintain
a record of what changes/contributions they have specific copyright on,
they should indicate their copyright in the commit message of the change
when they commit the change to the pvlib python repository.

License
=======

pvlib python is distributed under a 3-clause BSD license.
